@@ -71,18 +71,27 @@ async def update(force):
         page = await browser.new_page()
 
         try:
+            print("Before Log")
             await login(page)
 
+            print("Log")
+
             new_position = await Position.create(page)
 
+            print("After new pos")
+
             if force:
                 new_position = await new_position.update(page)
                 new_position.save()
 
             else:
                 old_position = Position.load()
+                print("After old")
                 if old_position != new_position:
+                    print("Dist")
+                    print(new_position)
                     new_position = await new_position.update(page)
+                    print("after update new")
                     new_position.save()
 
         except PlayWrightTimeout as e:
